@@ -1,7 +1,7 @@
-"""ds4drv - A DualShock 4 bluetooth driver for Linux."""
+"""ds4drv is a Sony DualShock 4 userspace driver for Linux."""
 
 __title__ = "ds4drv"
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 __author__ = "Christopher Rosell"
 __credits__ = ["Christopher Rosell", "George Gibbs", "Lauri Niskanen"]
 __license__ = "MIT"
